@@ -72,7 +72,8 @@ C*****resgn2.txt
       DOUBLE PRECISION WK(20),VT(500),BI(2,20,20),R(2,20,20),
      *RI(2,20,20)
 c       DOUBLE PRECISION WK(20),VT(500),BI(2,20,20),R(20,20),RI(2,20,20)
-      COMMON/RESGN2/WK,VT,BI,R,RI
+      INTEGER ERRNO1
+      COMMON/RESGN2/WK,VT,BI,R,RI,ERRNO1
 C*****kfasav.txt
       REAL PRE(500),PRV(500),FSER(500),FVAR(500),SSER(500),SVAR(500)
       DOUBLE PRECISION FSES(500,20),FSCV(500,20,20),SSES(500,20)
